@@ -22,14 +22,14 @@
 
 #include <Lum/Base/String.h>
 
+#include <Lum/Dlg/ActionDialog.h>
+
 #include <Lum/Model/Action.h>
 #include <Lum/Model/Integer.h>
 #include <Lum/Model/Selection.h>
 #include <Lum/Model/String.h>
 #include <Lum/Model/Table.h>
 
-#include <Lum/Dialog.h>
-
 #include "Configuration.h"
 
 typedef Lum::Model::StdRefTable<Tea,std::vector<Tea> > TeasModel;
@@ -66,7 +66,7 @@ public:
   }
 };
 
-class Selector : public Lum::Dialog
+class Selector : public Lum::Dlg::ActionDialog
 {
 private:
   Lum::Model::StringRef              value;
@@ -83,7 +83,8 @@ private:
 public:
   Selector(Lum::Model::Int* minutes, Lum::Model::Int *seconds);
 
-  void PreInit();
+  Lum::Object* GetContent();
+  void GetActions(std::vector<Lum::Dlg::ActionInfo>& actions);
 
   void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg);
 };
